diff Core.lua @ 185:a7f2ba17c39a v90

Shadowlands pre-patch update.
author yellowfive
date Tue, 13 Oct 2020 10:49:07 -0700
parents eec8032ba9df
children 23b740b4c93a
line wrap: on
line diff
--- a/Core.lua	Sat Feb 15 11:17:00 2020 -0800
+++ b/Core.lua	Tue Oct 13 10:49:07 2020 -0700
@@ -46,8 +46,9 @@
 			LastVersion = 0,           -- used to clean out old stuff	
 			FirstUse = true,           -- true if this is first time use, gets cleared after seeing the export help splash window
 			Talents = {},              -- for each spec, selected talents
-			Essences = {},             -- for each spec, selected essences
-			UnlockedEssences = {},     -- unlocked essences for this character
+			Soulbinds = {},            -- selected nodes in each soulbind tree for this character
+			ActiveSoulbinds = {},      -- for each spec, active soulbind
+			UnlockedConduits = {},     -- unlocked conduits for this character
 			Equipped = {},             -- for each spec, slot id to item info
 			BagItems = {},             -- list of item info for bags
 			BankItems = {},            -- list of item info for bank
@@ -708,4 +709,10 @@
 
 function Amr:Test()
 	
+	--local item = Item:CreateFromItemID(171416)
+	--local blah = C_LegendaryCrafting.GetRuneforgePowers(item:GetItemLocation())
+
+	--local info = C_LegendaryCrafting.GetRuneforgePowerInfo(30)
+
+	--print(Amr:dump(info))
 end